@@ -115,16 +115,13 @@ let files: Vec::<PathBuf> = Dowser::default()
 
 mod ext;
 mod entry;
-mod hash;
 mod iter;
 mod par;
 pub mod utility;
 
 
 
+pub(crate) use entry::Entry;
 pub use ext::Extension;
 pub use iter::Dowser;
 pub use par::DirConcurrency;
-
-pub(crate) use entry::Entry;
-pub(crate) use hash::NoHashState;
